# Copyright 2026 UCP Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# generated by datamodel-codegen
# pylint: disable=all
# pyformat: disable

from __future__ import annotations

from typing import Literal

from pydantic import BaseModel, ConfigDict


class MessageWarning(BaseModel):
    model_config = ConfigDict(
        extra="allow",
    )
    type: Literal["warning"]
    """
    Message type discriminator.
    """
    path: str | None = None
    """
    JSONPath (RFC 9535) to related field (e.g., $.line_items[0]).
    """
    code: str
    """
    Warning code. Machine-readable identifier for the warning type (e.g., final_sale, prop65, fulfillment_changed, age_restricted, etc.).
    """
    content: str
    """
    Human-readable warning message that MUST be displayed.
    """
    content_type: Literal["plain", "markdown"] | None = "plain"
    """
    Content format, default = plain.
    """
